@@ -31,6 +31,18 @@ func TestGetOutputter(t *testing.T) {
 			input:    OutputJUnit,
 			expected: NewJUnit(os.Stdout, false),
 		},
+		{
+			input:    OutputGitHub,
+			expected: NewGitHub(os.Stdout),
+		},
+		{
+			input:    OutputAzureDevOps,
+			expected: NewAzureDevOps(os.Stdout),
+		},
+		{
+			input:    OutputSARIF,
+			expected: NewSARIF(os.Stdout),
+		},
 		{
 			input:    "unknown_format",
 			expected: NewStandard(os.Stdout),
