@@ -19,7 +19,7 @@ func TestIniParser(t *testing.T) {
 
 	# Test comment`
 
-	var input interface{}
+	var input any
 	if err := parser.Unmarshal([]byte(sample), &input); err != nil {
 		t.Fatalf("parser should not have thrown an error: %v", err)
 	}
@@ -28,9 +28,9 @@ func TestIniParser(t *testing.T) {
 		t.Error("there should be information parsed but its nil")
 	}
 
-	inputMap := input.(map[string]interface{})
+	inputMap := input.(map[string]any)
 	item := inputMap["Local Variables"]
-	if len(item.(map[string]interface{})) == 0 {
+	if len(item.(map[string]any)) == 0 {
 		t.Error("there should be at least one item defined in the parsed file, but none found")
 	}
 }
@@ -39,7 +39,7 @@ func TestConvertTypes(t *testing.T) {
 	testTable := []struct {
 		name           string
 		input          map[string]string
-		expectedOutput interface{}
+		expectedOutput any
 	}{
 		{"Test number literal", map[string]string{"test": "3.0"}, 3.0},
 		{"Test string literal", map[string]string{"test": "conftest"}, "conftest"},
