@@ -10,7 +10,7 @@ import (
 type Parser struct{}
 
 // Unmarshal unmarshals JSON files.
-func (p *Parser) Unmarshal(data []byte, v interface{}) error {
+func (p *Parser) Unmarshal(data []byte, v any) error {
 	if err := jsonc.Unmarshal(data, v); err != nil {
 		return fmt.Errorf("unmarshal jsonc: %w", err)
 	}
